{% extends 'base.html' %}


{% block nav_home %} layui-this {% endblock %}
{% block nav_jubing %} {% endblock %}
{% block nav_nav_colors %}  {% endblock %}


{% block body %}
<div class=".container">
    <div class="card">
      <div class="card-body">
        This is some text within a card body.
      </div>
    </div>

    <div class="card">
  <div class="card-body">
    This is some text within a card body.
  </div>
</div>
</div>
{% endblock %}