from airclick.action.path import path
from typing import List
from airclick.action.path import path


def perform(*paths: List[path]) -> None:
    """
    执行手势操作

    :param paths: 需要执行的路径对象列表
    """
    pass
